@@ -204,7 +204,21 @@ def plot_unit_cell_volume_change(trajectories, labels):
 
 def get_octahedral_angles_and_distances(center_atom_symbol, vertex_atom_symbol, trajectory, plane_of_interest='xy'):
     '''
-    Plots the angle connecting octahedral centers over a trajectory.
+    Calculate angles and distances between atoms in octahedral coordination.
+    Returns two DataFrames:
+        angle_data:
+            step    index of the Trajectory or list of structures
+            angle   center-equitorial vertex-center angle
+            vertex_displacement distance from equitorial vertex to midpoint of center-center
+            atoms   indices of the atoms forming angle (center,vertex,center)
+            tilt_angle  angle between apical vertex atoms and normal of the plane of interest
+            tilt_atoms  indices of center atom and two apical vertex atoms
+            in_plane_angle  angle projected onto the plane of interest
+        distance_data:
+            step    index of the Trajectory or list of structures
+            distance    distance from center atom to equitorial vertex atom
+            atoms   indices of center and vertex atom separated by distance
+
     :param center_atom_symbol: name of atom at octahedral centers (e.g. 'Pb')
     :type center_atom_symbol: str
     :param vertex_atom_symbol: name of atom at octahedral vertices (e.g. 'I')
@@ -212,7 +226,7 @@ def get_octahedral_angles_and_distances(center_atom_symbol, vertex_atom_symbol,
     :param trajectory: ASE trajectory
     :param plane_of_interest: way to specify equitorial plane (e.g. 'xy')
     :type plane_of_interest: str
-    :return: tuple of DataFrame (angles, distances)
+    :return: two DataFrames (angle_data, distance_data)
     :rtype: tuple
     '''
 
@@ -274,12 +288,8 @@ def get_octahedral_angles_and_distances(center_atom_symbol, vertex_atom_symbol,
                                                            apical_vertex_atom_indices[1],
                                                            mic=True,
                                                            vector=True)
-                        pb_pb_vector = atoms.get_distance(nearest_center_atom_index,
-                                                          center_atom_index,
-                                                          mic=True,
-                                                          vector=True)
+
                         apical_vector = apical_vector / np.linalg.norm(apical_vector)
-                        pb_pb_vector = pb_pb_vector / np.linalg.norm(pb_pb_vector)
                         ab_indices = np.setxor1d([0,1,2], [apical_axis])
                         ab_normal_vector = np.cross(atoms.cell[ab_indices[0]], atoms.cell[ab_indices[1]])
                         ab_normal_vector = ab_normal_vector / np.linalg.norm(ab_normal_vector)
@@ -303,18 +313,23 @@ def get_octahedral_angles_and_distances(center_atom_symbol, vertex_atom_symbol,
                         proj_vector_2 = proj_vector_2 / np.linalg.norm(proj_vector_2)
                         in_plane_angle = 180.0/np.pi * np.arccos(np.dot(proj_vector_1, proj_vector_2))
 
+                        # Calculate displacement of vertex atom from the midpoint of the center to center vector
+                        c_v_nc_angle = atoms.get_angle(center_atom_index,
+                                                       vertex_atom_index,
+                                                       nearest_center_atom_index,
+                                                       mic=True)
+                        c_nc_distance = all_distances[center_atom_index, nearest_center_atom_index]
+                        vertex_displacement = (c_nc_distance/2.0)/np.tan(c_v_nc_angle/2.0*np.pi/180.0)
+
                         angle_data = angle_data.append(pd.DataFrame(dict(step=step,
-                                                                         angle=atoms.get_angle(center_atom_index,
-                                                                                               vertex_atom_index,
-                                                                                               nearest_center_atom_index,
-                                                                                               mic=True),
+                                                                         angle=c_v_nc_angle,
+                                                                         vertex_displacement=vertex_displacement,
                                                                          atoms=','.join(map(str, [center_atom_index,
                                                                                                   vertex_atom_index,
                                                                                                   nearest_center_atom_index])),
                                                                          tilt_angle=tilt_angle,
                                                                          tilt_atoms=','.join(map(str,
-                                                                                                 [nearest_center_atom_index,
-                                                                                                  center_atom_index,
+                                                                                                 [center_atom_index,
                                                                                                   apical_vertex_atom_indices[0],
                                                                                                   apical_vertex_atom_indices[1]])),
                                                                          in_plane_angle=in_plane_angle),
@@ -331,7 +346,7 @@ def get_octahedral_angles_and_distances(center_atom_symbol, vertex_atom_symbol,
 
     return angle_data, distance_data
 
-def get_penetration_distances(atoms, center_species, vertex_species, apical_direction):
+def get_penetration_distances(atoms, center_species, vertex_species, apical_direction, n_atoms=None):
     '''
     Calculate the position of ammonium nitrogen atoms relative to other atoms:
         N to vertex distance: mean distance between each ammonium N atom and the 4 nearest vertex atoms
@@ -345,8 +360,10 @@ def get_penetration_distances(atoms, center_species, vertex_species, apical_dire
     :type vertex_species: str
     :param apical_direction: direction normal to the plane containing sheets of octahedra
     :type apical_direction: 3 element array
+    :param n_atoms: (optional) list of atom indices for the ammonium nitrogen atoms to analyze
+    :type n_atoms: list of int
     :return: N to vertex distances, N to center distance, penetration distances
-    :rtype: tuple
+    :rtype: DataFrame
     '''
 
     # Get unit vector in apical direction
@@ -356,6 +373,7 @@ def get_penetration_distances(atoms, center_species, vertex_species, apical_dire
     n_to_x_dist = []
     c_to_n_dist = []
     n_to_apical_x_dist = []
+    n_to_3x_dist = []
 
     # Save static info about the crystal structure
     all_vectors = atoms.get_all_distances(mic=True, vector=True)
@@ -363,19 +381,44 @@ def get_penetration_distances(atoms, center_species, vertex_species, apical_dire
     x_indices = [a.index for a in atoms if a.symbol == vertex_species]
     c_indices = [a.index for a in atoms if a.symbol == center_species]
 
-    for n_atom in find_ammonium_atoms(atoms):
-        # Sort nitrogen to vertex atom vectors by length
+    if n_atoms is None:
+        n_atoms = find_ammonium_atoms(atoms)
+
+    for n_atom in n_atoms:
+        # Need to use a supercell because an single atom index
+        # may need to be used more than once, but in difference unit cells
+        # First get all n-x distances
+        n_x_vectors = all_vectors[n_atom][x_indices]
+
+        # Then get n-x distances to adjacent unit cells
+        translated_n_x_vectors = np.empty((len(n_x_vectors)*7, 3))
+        for i,v in enumerate(n_x_vectors):
+            # Add vectors from n_atom to x atoms translated to unit cells +/- in a,b,c
+            translated_n_x_vectors[7 * i] = v
+            translated_n_x_vectors[7 * i + 1] = v + atoms.cell[0]
+            translated_n_x_vectors[7 * i + 2] = v - atoms.cell[0]
+            translated_n_x_vectors[7 * i + 3] = v + atoms.cell[1]
+            translated_n_x_vectors[7 * i + 4] = v - atoms.cell[1]
+            translated_n_x_vectors[7 * i + 5] = v + atoms.cell[2]
+            translated_n_x_vectors[7 * i + 6] = v - atoms.cell[2]
+
+        # Get 3 closest X atoms to the N atom
+        smallest_three_n_x_vectors = translated_n_x_vectors[
+            np.argsort(np.linalg.norm(translated_n_x_vectors, axis=1))[:3]]
+        n_to_3x_dist.append(np.mean(np.linalg.norm(smallest_three_n_x_vectors, axis=1)))
+
         # Out of the shortest 8, choose the four vertex atoms farthest from the closest center atom in the apical dir.
-        nearest_eight_x_atoms = np.take(x_indices, np.argsort(all_distances[n_atom][x_indices]))[:8]
+        smallest_eight_n_x_vectors = translated_n_x_vectors[
+            np.argsort(np.linalg.norm(translated_n_x_vectors,axis=1))[:8]]
         nearest_c_atom = np.array(c_indices)[np.argsort(all_distances[n_atom][c_indices])][0]
-        c_to_nearest_eight_x_vectors = all_vectors[nearest_c_atom][nearest_eight_x_atoms]
+        c_to_nearest_eight_x_vectors = smallest_eight_n_x_vectors + all_vectors[nearest_c_atom][n_atom]
         c_to_nearest_eight_x_apical_vectors = np.outer(np.dot(c_to_nearest_eight_x_vectors, apical_direction),
                                                        apical_direction)
         c_to_nearest_eight_x_apical_distances = np.abs(np.linalg.norm(c_to_nearest_eight_x_apical_vectors, axis=1))
-        nearest_four_apical_x_indices = nearest_eight_x_atoms[np.argsort(c_to_nearest_eight_x_apical_distances)][-4:]
+        n_to_four_apical_x_vectors = smallest_eight_n_x_vectors[np.argsort(c_to_nearest_eight_x_apical_distances)[-4:]]
 
         # Save the mean distance from an N atom to the nearest 4 apical vertex atoms
-        n_to_x_dist.append(np.mean(all_distances[n_atom][nearest_four_apical_x_indices]))
+        n_to_x_dist.append(np.mean(np.linalg.norm(n_to_four_apical_x_vectors, axis=1)))
 
         # Get distance from N atom to nearest center atom in apical direction
         n_to_nearest_c_vector = all_vectors[n_atom][nearest_c_atom]
@@ -383,12 +426,11 @@ def get_penetration_distances(atoms, center_species, vertex_species, apical_dire
         n_to_nearest_c_apical_distance = np.linalg.norm(n_to_nearest_c_apical_vector)
         c_to_n_dist.append(n_to_nearest_c_apical_distance)
 
-        # Get the distance from the N atom to the 4 nearest vertex atoms that are within 1.5 Ang. of the N atom in the z-direction
-        n_to_nearest_four_apical_x_vectors = all_vectors[n_atom][nearest_four_apical_x_indices]
-        n_to_nearest_four_apical_x_apical_vectors = np.outer(np.dot(n_to_nearest_four_apical_x_vectors,
+        # Get the distance from the N atom to the 4 nearest vertex atoms in the apical direction
+        n_to_four_apical_x_apical_vectors = np.outer(np.dot(n_to_four_apical_x_vectors,
                                                                     apical_direction),
                                                              apical_direction)
-        n_to_x_apical_distances = np.linalg.norm(n_to_nearest_four_apical_x_apical_vectors, axis=1)
+        n_to_x_apical_distances = np.linalg.norm(n_to_four_apical_x_apical_vectors, axis=1)
 
         # Determine if the penetration distance is:
         # positive (N atom between apical vertex atoms and center atoms)
@@ -404,7 +446,8 @@ def get_penetration_distances(atoms, center_species, vertex_species, apical_dire
 
     return pd.DataFrame(dict(n_to_x_distances=n_to_x_dist,
                              c_to_n_distances=c_to_n_dist,
-                             penetration_distances=n_to_apical_x_dist))
+                             penetration_distances=n_to_apical_x_dist,
+                             n_to_3x_distances=n_to_3x_dist))
 
 def vasp_to_trajectory(outcar_filenames, trajectory_filename):
     '''
@@ -574,6 +617,8 @@ def plot_trajectory_angles_and_distances(traj, atom1, atom2, label):
 
     ax = plt.subplot(2,1,1)
     angle_data.pivot(index='step', columns='atoms', values='angle').plot(ax=ax)
+    # Plot the mean angle
+    angle_data.pivot(index='step', columns='atoms', values='angle').mean(axis=1).plot(ax=ax, style='--')
     plt.title(label)
     #plt.legend(title='Angle No.', loc='center left', bbox_to_anchor=(1, 0.5))
     plt.gca().get_legend().remove()
@@ -727,9 +772,6 @@ def compare_relaxations(relaxation_summary):
     :return:
     :rtype:
     '''
-    plt.style.reload_library()
-    plt.rcdefaults()
-    plt.style.use(['acs'])
 
     # Plot relative change in volume
     fig = plt.gcf()
@@ -762,14 +804,7 @@ def compare_relaxations(relaxation_summary):
     plt.xticks([])
     plt.legend(loc='best', edgecolor='w', borderpad=0)
 
-    # Add panel labels
-    for i, label in enumerate(('a', 'b')):
-        ax = plt.subplot(1, 2, i + 1)
-        ax.text(-0.2, 1.1, label, transform=ax.transAxes,
-                fontsize=6, fontweight='bold', va='top', ha='right')
-
     plt.tight_layout()
-    plt.subplots_adjust(left=0)
 
 def get_vasp_runtimes(exclude_keyword=None):
     '''
@@ -1095,8 +1130,6 @@ def plot_bands(e_mk,
     else:
         plt.title(f'Band {bands_to_highlight}')
 
-    plt.tight_layout()
-
 
 
 def plot_band_path(structure_file, band_path_str):
@@ -1144,3 +1177,24 @@ def plot_band_path(structure_file, band_path_str):
             file.write(f'{p}: {bp.special_points[p]}\n')
 
     return fig
+
+def plot_pdos(calc, species, species_orbitals, smoothing_width=0.05, npts=601, energy_limits=None, soc=False):
+    '''
+
+    :param calc: band structure calculator
+    :type calc: GPAW
+    :param species: atomic species to plot e.g. ['Pb', 'I']
+    :type species: list of str
+    :param species_orbitals: orbitals to plot, same length as species e.g. ['sp', 'p']
+    :type species_orbitals: list of str
+    :param smoothing_width: passed to GPAW row_dos method, smooths the curves
+    :type smoothing_width: float
+    :param npts: number of data points in the energy dimension to calculate
+    :type npts: int
+    :param energy_limits: min and max energy to plot
+    :type energy_limits: 2-tuple of float
+    :param soc:
+    :type soc:
+    :return:
+    :rtype:
+    '''
\ No newline at end of file
